%%
%% Nzev: Tisk zadn se strojov itelnmi daji
%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{scanexam}
[2009/01/12 version 0.5 Machine readable information]

%%
%% Tato tda je zaloena na LaTeXovsk td 'article'. Podporovan volby
%% tdy 'article' jsou pouze draft/final a 10pt/11pt/12pt.
%%

\def\clsopt@status{final}
\def\clsopt@fntsize{11pt}

\DeclareOption{draft}{\def\clsopt@status{draft}}
\DeclareOption{final}{\def\clsopt@status{final}}

\DeclareOption{10pt}{\def\clsopt@fntsize{10pt}}
\DeclareOption{11pt}{\def\clsopt@fntsize{11pt}}
\DeclareOption{12pt}{\def\clsopt@fntsize{12pt}}

\ProcessOptions

\LoadClass[a4paper,oneside,\clsopt@status,\clsopt@fntsize]{article}


%%
%% Implementace strojov itelnch prvk - rozmry
%%

% Strojov iteln informace se skldaj z obdlnk:
\newdimen\size@rect@length      \size@rect@length=5mm    % dlka
\newdimen\size@rect@thick       \size@rect@thick=0.8mm   % tlouka

% Pokud informaci vypluje lovk, je nutn mu obdlnky naznait. K tomu
% se jejich rohy vyzna arou nsledujc tlouky.
\newdimen\size@marg@thick       \size@marg@thick=0.1pt

% Dlka ry vyznaujc vnitn roh ablony ve tvercov sti
% z elementrnch obdlnk.
\newdimen\size@marg@inner       \size@marg@inner=0.2mm

% Pokud po sob nsleduje vce elementrnch polek (slice, zakrtvac
% polko), jsou oddleny nsledujc mezerou.
\newdimen\size@elem@skip        \size@elem@skip=2mm

% Kad strojov iteln informace na strnce mus bt doplnna
% synchronizanmi znakami na okraji. Synchronizan znaky jsou od okraj
% tiskovho zrcadla odsazeny nsledujc mezerou.
\newdimen\size@sync@skip        \size@sync@skip=8mm

% Posun ve tvercov sti z elementrnch obdlnk (uiten napklad
% pro pole slice).
\newdimen\size@rect@shift

% Pepotn dopotvanch rozmr podle aktulnch hodnot.
\def\size@refresh{%
    \size@rect@shift=\size@rect@length
    \advance\size@rect@shift by -\size@rect@thick
}

% Iniciln refresh.
\size@refresh


%%
%% Styly
%%

% Popis datov poloky.
\def\fielddesc@topstyle{\small\itshape\bfseries}



%%
%% Pomocn makra - etzce bit
%%
%% Nsledujc makra implementuj zpracovn bitovch etzc. Primrnm
%% elem je vykreslovn obdlnk v ablon. Obdlnky tvoc ablonu
%% jsou oslovny. Makro kreslc ablonu potom v argumentu bere bitov
%% etzec, jeho dlka odpovd potu obdlnk v ablon. Bit na i-t
%% pozici uruje, zda je i-t obdlnek vykreslen nebo ponechn przdn.
%%
%% Pouit:
%% Volajc makro mus nejprve uloit bitov etzec do makra
%% \bit@sequence. Nsledn me opakovan volat makro \bit@test. Opakovan
%% voln \bit@test prochz postupn (a destruktivn) posloupnost
%% v \bit@sequence. Pokud je hodnota aktulnho bitu 1, makro \bit@test
%% expanduje na svj argument, jinak jej zahod. Makro \bit@test svj
%% argument zahazuje tak po vyprzdnn \bit@sequence.

% Srovnvac hodnota - bit je nula.
\def\bit@zero{0}

% Srovnvac hodnota - bit je jedna.
\def\bit@one{1}

% Promnn pro uloen posloupnosti bit.
\def\bit@sequence{}

% Pomocn promnn do n je posouvn pro zpracovn prvn prvek
% posloupnosti.
\def\bite@now{}

% Posune posloupnost v \bit@sequence a odstrann bit ulo do \bit@now.
\def\bit@take #1#2\relax{%
    \def\bit@now{#1}%
    \def\bit@sequence{#2}%
}

% Zavol \bit@take a podle nslednho obsahu \bit@now expanduje na svj
% argument nebo przdnou posloupnost token.
\def\bit@test#1{%
    \expandafter\bit@take\bit@sequence\relax\relax
    \ifx \bit@now\bit@one #1\fi
}


%%
%% Pomocn makra - cykly pes \relax-terminated posloupnosti token
%%

% Srovnvac hodnota pro rozpoznn konce posloupnosti.
\def\loop@relax{\relax}

% Pomocn makro zahod svj argument (pi ukonen cyklu).
\def\loop@droparg#1{}

% Pomocn makro zahod zbytek \relax-terminated posloupnosti (pi ukonen
% cyklu).
\def\loop@droprelax#1\relax{}


%%
%% Implementace strojov itelnch prvk - elementrn obdlnky
%%
%% Vechny strojov iteln informace se skldaj z jedinho typu
%% obdlnk, kter m vak dv orientace:
%%      - horizontln (_) a
%%      - vertikln (|)
%% Nsledujc dv makra slou k vykreslen tchto obdlnk se spodn
%% hranou zarovnanou na baseline dku do boxu ky 0pt (usnaduje
%% skldn prvk z vce obdlnk).

% Horizontln obdlnek.
\def\rect@h{%
    \hbox to 0pt{%
        \vrule width \size@rect@length height \size@rect@thick depth 0pt\hss
    }%
}

% Vertikln obdlnek.
\def\rect@v{%
    \hbox to 0pt{%
        \vrule width \size@rect@thick height \size@rect@length depth 0pt\hss
    }%
}


%%
%% Implementace strojov itelnch prvk - znaky orientujc strnku
%%
%% Oba horn rohy a lev doln roh strojov snmateln strnky mus
%% obsahovat vodc znaky - tverce velikosti elementrnch obdlnk.
%% tverce udvaj jednak orientaci strnky, jednak rozmry tiskovho
%% zrcadla a umstn ostatnch vodcch znaek na strnce.
%%

% Makro se vol na zatku strnky, vytiskne vodc tverce v hornch
% rozch strnky.
\def\marks@top{%
    \vbox to \size@rect@length{%
        \offinterlineskip
        \hbox to \textwidth{%
            \hbox to 0pt{%
                \hss
                \vrule width \size@rect@length height \size@rect@length depth 0pt
                \kern\size@sync@skip
            }%
            \hfil
            \hbox to 0pt{%
                \kern\size@sync@skip
                \vrule width \size@rect@length height \size@rect@length depth 0pt
                \hss
            }%
        }%
    }%
}

% Makro se vol na konci strnky, vytiskne vodc tverec v levm dolnm
% rohu strnky.
\def\marks@bottom{%
    \hbox to \textwidth{%
        \hbox to 0pt{%
            \hss
            \vrule width \size@rect@length height \size@rect@length depth 0pt
            \kern\size@sync@skip
        }%
        \hfil
    }%
}


%%
%% Implementace strojov itelnch prvk - prvky okraj
%%
%% Nsledujc makra slou k vyznaovn tvar vyskldanch z
%% elementrnch obdlnk. Motivovna jsou ablonou po slici, ale mly
%% by postait pro libovoln tvar, kter lze z obdlnk vyskldat.

% Lev okraj obdlnku - petk vlevo.
\def\margin@lft{\hbox to 0pt{%
    \hss\vrule width \size@marg@thick height \size@rect@thick depth 0pt}}

% Prav okraj obdlnku - petk vpravo.
\def\margin@rt{\hbox to 0pt{%
    \vrule width \size@marg@thick height \size@rect@thick depth 0pt\hss}}

% Spodn lev okraj obdlnku - petk vpravo.
\def\margin@llft{\hbox to 0pt{%
    \vrule width \size@rect@thick height 0pt depth \size@marg@thick\hss}}

% Horn lev okraj obdlnku - petk vpravo.
\def\margin@ulft{\hbox to 0pt{%
    \raise \size@rect@thick \hbox{%
        \vrule width \size@rect@thick height \size@marg@thick depth 0pt}%
    \hss}}

% Spodn prav okraj obdlnku - petk vlevo.
\def\margin@lrt{\hbox to 0pt{%
    \hss\vrule width \size@rect@thick height 0pt depth \size@marg@thick}}

% Horn lev okraj obdlnku - petk vpravo.
\def\margin@urt{\hbox to 0pt{%
    \hss \raise \size@rect@thick \hbox{%
        \vrule width \size@rect@thick height \size@marg@thick depth 0pt}%
    }}

% Vnitn lev doln roh.
\def\margin@inner@llft{\hbox to 0pt{\hskip \size@rect@thick
    \raise \size@rect@thick \hbox{%
        \vrule width \size@marg@thick height \size@marg@inner depth 0pt
        \vrule width \size@marg@inner height 0pt depth \size@marg@thick
    }%
    \hss}}

% Vnitn lev horn roh.
\def\margin@inner@ulft{\hbox to 0pt{\hskip \size@rect@thick
    \vrule width \size@marg@thick height 0pt depth \size@marg@inner
    \vrule width \size@marg@inner height \size@marg@thick depth 0pt
    \hss}}

% Vnitn prav doln roh.
\def\margin@inner@lrt{\hbox to 0pt{\hss
    \raise \size@rect@thick \hbox{%
        \vrule width \size@marg@inner height 0pt depth \size@marg@thick
        \vrule width \size@marg@thick height \size@marg@inner depth 0pt
    }%
    \hskip \size@rect@thick}}

% Vnitn prav horn roh.
\def\margin@inner@urt{\hbox to 0pt{\hss
    \vrule width \size@marg@inner height \size@marg@thick depth 0pt
    \vrule width \size@marg@thick height 0pt depth \size@marg@inner
    \hskip \size@rect@thick}}


%%
%% Implementace strojov itelnch prvk - \checkbox
%%
%% Makro vysz jeden checkbox. V jedinm argumentu je zadvn titn stav
%% chekboxu jako jeden bit: 0 (nezatren), 1 (zatren). Pokud je
%% v argumentu nco jinho, pravdpodobn se to cel rozbije.

\def\checkbox#1{%
    \def\bit@sequence{#1}%
    \hbox to \size@rect@length{%
        % okraje vlevo
        \margin@lft
        \margin@llft
        \margin@ulft
        % vpl v zvislosti na argumentu
        \bit@test{\rect@h}\hfil
        % okraje vpravo
        \margin@rt
        \margin@lrt
        \margin@urt
    }%
}


%%
%% Implementace strojov itelnch prvk - slice
%%
%% Kad slice se skld ze sedmi obdlnk, kde obdlnky 1,3,6,4 a
%% 2,4,7,5 tvo tverce se spolenou stranou 4.
%%       ---3---
%%       |     |
%%       1     6
%%       |     |
%%       ---4---
%%       |     |
%%       2     7
%%       |     |
%%       ---5---
%% Spodn hrany obdlnk 2, 5 a 7 jsou zarovnny na baseline. Obdlnky
%% 1, 3, 4 a 6 je nutn zvednout (\raise). Obdlnek 3 je zvednut o
%% 2\size@rect@shift, obdlnky 1, 4 a 6 o 1\size@rect@shift

% \digit
% Makro vysz slici zadanou v argumentu. Pokud je argument przdn,
% vysz msto pro jednu slici. Pokud argument obsahuje nco jinho ne
% slici, pravdpodobn se bude chovat jako \relax, ale tak se to me
% cel rozbt.
\def\digit#1{%
    % vodc znaka pod slic
    \lower \size@rect@shift \rect@h
    % tlo slice
    \csname digit@#1\endcsname
}

% \digit@ - ablona pro slici
\def\digit@{\digit@ll{0000000}}

% \digit@0..\digit@9 - slice 0..9
\expandafter\def\csname digit@0\endcsname{\digit@ll{1110111}}
\expandafter\def\csname digit@1\endcsname{\digit@ll{0000011}}
\expandafter\def\csname digit@2\endcsname{\digit@ll{0111110}}
\expandafter\def\csname digit@3\endcsname{\digit@ll{0011111}}
\expandafter\def\csname digit@4\endcsname{\digit@ll{1001011}}
\expandafter\def\csname digit@5\endcsname{\digit@ll{1011101}}
\expandafter\def\csname digit@6\endcsname{\digit@ll{1111101}}
\expandafter\def\csname digit@7\endcsname{\digit@ll{0010011}}
\expandafter\def\csname digit@8\endcsname{\digit@ll{1111111}}
\expandafter\def\csname digit@9\endcsname{\digit@ll{1011111}}

% \digit@ll
% Low-level makro vysz ablonu pro jednu slici a vypln v n obdlnky
% podle sedmi bit zadanch v argumentu jako posloupnost 0 a 1. Pokud je
% v argumentu nco jinho ne sedm bit, nejsp se to cel rozbije.
\def\digit@ll#1{\hbox to \size@rect@length{%
    \def\bit@sequence{#1}%
    % okraje vlevo
    \margin@lft
    \raise \size@rect@shift \margin@lft
    \raise 2\size@rect@shift \margin@lft
    \margin@llft
    \raise 2\size@rect@shift \margin@ulft
    \margin@inner@llft
    \raise \size@rect@shift \margin@inner@ulft
    \raise \size@rect@shift \margin@inner@llft
    \raise 2\size@rect@shift \margin@inner@ulft
    % 7 obdlnk
    \bit@test{\raise \size@rect@shift \rect@v}%     obdlnek 1
    \bit@test{\rect@v}%                             obdlnek 2
    \bit@test{\raise 2\size@rect@shift \rect@h}%    obdlnek 3
    \bit@test{\raise \size@rect@shift \rect@h}%     obdlnek 4
    \bit@test{\rect@h}%                             obdlnek 5
    \hss
    \bit@test{\raise \size@rect@shift \rect@v}%     obdlnek 6
    \bit@test{\rect@v}%                             obdlnek 7
    \hskip \size@rect@thick
    % okraje vpravo
    \margin@lrt
    \raise 2\size@rect@shift \margin@urt
    \margin@rt
    \raise \size@rect@shift \margin@rt
    \raise 2\size@rect@shift \margin@rt
    \margin@inner@lrt
    \raise \size@rect@shift \margin@inner@urt
    \raise \size@rect@shift \margin@inner@lrt
    \raise 2\size@rect@shift \margin@inner@urt
}}


%%
%% Implementace strojov itelnch prvk - sla
%%
%% sla se skldaj z slic. Definujeme obecn makra \digitsleft
%% a \digitsright pro tisk pole s danm potem cifer a ppadn
%% pedtitnm slem zarovnanm vlevo, resp. vpravo. Zbyl voln cifry
%% jsou bu ponechny przdn, nebo vyplnny libovolnou slic. Pokud je
%% zadan slo del ne poet cifer, vysz se pouze zatek sla tak,
%% aby byl zachovn poadovan poet cifer.
%%
%% Ostatn (high-level) makra pro tisk pol pro specifick sla jsou
%% instanc jednoho z tchto dvou maker.

% Poet cifer titnho pole.
\newcount\dfld@length

% Poet cifer pedtitnho sla.
\newcount\dfld@digits

% Vzornk slic. Zmrn se pouvaj low-level makra msto makra \digit,
% protoe makro \digit sz i vodc znaky pod sla, m zbyten
% zvtuje vku vzornku.
\def\digitsall{%
    \csname digit@\endcsname\kern\size@elem@skip
    \csname digit@0\endcsname\kern\size@elem@skip
    \csname digit@1\endcsname\kern\size@elem@skip
    \csname digit@2\endcsname\kern\size@elem@skip
    \csname digit@3\endcsname\kern\size@elem@skip
    \csname digit@4\endcsname\kern\size@elem@skip
    \csname digit@5\endcsname\kern\size@elem@skip
    \csname digit@6\endcsname\kern\size@elem@skip
    \csname digit@7\endcsname\kern\size@elem@skip
    \csname digit@8\endcsname\kern\size@elem@skip
    \csname digit@9\endcsname
}

% \digitsleft - zarovn slo vlevo
% #1 - poet cifer
% #2 - slo, kter se m pedvyplnit (me bt przdn)
% #3 - slice pro vyplnn zbylch pozic (me bt przdn)
\def\digitsleft#1#2#3{%
    \edef\arg{#1}%
    \expandafter\dfld@length\arg\relax
    \dfld@digits=0%
    \edef\arg{#2}%
    \expandafter\dfld@count \arg\relax
    \expandafter\dfld@number \arg\relax\relax%
    \dfld@padding{#3}%
}

% \digitsright - zarovn slo vpravo
% #1 - poet cifer
% #2 - slo, kter se m pedvyplnit (me bt przdn)
% #3 - slice pro vyplnn zbylch pozic (me bt przdn)
\def\digitsright#1#2#3{%
    \edef\arg{#1}%
    \expandafter\dfld@length\arg\relax
    \dfld@digits=0%
    \edef\arg{#2}%
    \expandafter\dfld@count \arg\relax
    \dfld@padding{#3}%
    \expandafter\dfld@number \arg\relax\relax%
}

% Toto makro zvt hodnotu \dfld@digits o jedna za kad token natan
% posloupnosti pedchzejc \relax.
\def\dfld@count#1{%
    \def\loop@test{#1}%
    \ifx\loop@test\loop@relax
        \let\next=\relax
    \else
        \advance\dfld@digits by 1
        \let\next=\dfld@count
    \fi
    \next
}

% Makro vytiskne nejve \dfld@length prvnch slic z sla #1. Za kad
% vytitn slo zmen \dfld@length a \dfld@digits o jedna (mus zstat
% zachovn rozdl mezi nimi, aby sprvn pracovalo makro \dfld@padding,
% kter je v ppad doleva zarovnanho sla volno a po \dfld@number).
\def\dfld@number#1{%
    \def\loop@test{#1}%
    \ifx \loop@test\loop@relax
        \let\next=\relax
    \else
        \ifnum\dfld@length=0
            \let\next=\loop@droprelax
        \else
            \advance\dfld@length by -1
            \advance\dfld@digits by -1
            \digit{#1}%
            \ifnum\dfld@length>0\kern\size@elem@skip \fi
            \let\next=\dfld@number
        \fi
    \fi
    \next
}

% Makro tiskne slici #1, ppadn przdnou ablonu pro slici, dokud
% plat \dfld@length>0 a \dfld@length>\dfld@digits (za kad vytitn
% polko sniuje \dfld@length o jedna).
\def\dfld@padding#1{%
    \ifnum \dfld@length=0
        \let\next=\loop@droparg
    \else \ifnum \dfld@length>\dfld@digits
        \advance\dfld@length by -1
        \digit{#1}%
        \ifnum\dfld@length>0\kern\size@elem@skip \fi
        \let\next=\dfld@padding
    \else
        \let\next=\loop@droparg
    \fi\fi
    \next{#1}%
}


%%
%% Podpora pro definice high-level datovch slicovch poloek
%%

% Vysz peddefinovan pole slic '#2' podle nastaven pro ablonu '#1'.
% Za povinnmi prvnmi dvma argumenty me nsledovat nepovinn tet
% argument udvajc pedtitnou hodnotu pole.
\def\digitsfield#1#2{%
    \@ifnextchar[
    {\df@field{#1}{#2}}
    {\df@field{#1}{#2}[]}
}

% Low-level makro implementujc \digitsfield.
%   #1 - kd typu formule obsahujcho datovou poloku
%   #2 - jmno datov poloky
%   #3 - hodnota k pedvyplnn (me bt przdn)
\def\df@field#1#2[#3]{\hbox to 0pt{\hbox to \textwidth{%
    % horizontln umstn na dku
    \expandafter \hskip \csname #1@#2@skip\endcsname
    % makro \csname #1@#2@do\endcsname je identick s nkterm
    % z maker \df@do*
    \csname #1@#2@do\endcsname{#2}{#3}%
    % vyplnn zbytku dku
    \hfil
}\hss}}

% Sazba slicov datov poloky bez popisky.
%   #1 - jmno datov poloky
%   #2 - hodnota k pedvyplnn (me bt przdn)
\def\df@do#1#2{%
    \csname dffield@#1\endcsname{#2}%
}

% Sazba slicov datov poloky s popiskou vlevo.
%   #1 - jmno datov poloky
%   #2 - hodnota k pedvyplnn (me bt przdn)
\def\df@dolft#1#2{%
    \hbox to 0pt{\hss
        \fielddesc@topstyle\strut
        \csname #1name\endcsname%
        \quad
    }%
    \csname dffield@#1\endcsname{#2}%
}

% Sazba slicov datov poloky s popiskou nahoe.
%   #1 - jmno datov poloky
%   #2 - hodnota k pedvyplnn (me bt przdn)
\def\df@dotop#1#2{\vbox{%
    % sazba datov poloky do boxu kvli zjitn rozmr
    \setbox0=\hbox{\csname dffield@#1\endcsname{#2}}%
    % vycentrovan popis nad polokou
    \hbox to \wd0{\hss\fielddesc@topstyle
        \strut \csname #1name\endcsname\hss}%
    \medskip
    % ve vyszen datov poloka
    \box0%
}}


%%
%% Specifick typy sel
%%

% Typ formule
% (4 cifry, zarovnno doprava, vyplnno nulami)
\def\formtypename{Typ formul\'{a}\v{r}e}
\def\dffield@formtype#1{\digitsright{4}{#1}{0}}

% UO
% (7 cifer, zarovnno doleva, zbyl msto nevyplovno)
\def\uconame{u\v{c}o}
\def\dffield@uco#1{\digitsleft{7}{#1}{}}

% Body
% (3 cifry, zarovnno vpravo, zbyl msto nevyplovno)
\def\pointsname{body}
\def\dffield@points#1{\digitsright{3}{#1}{}}

% slo pkladu
% (2 cifry, zarovnno vpravo, zbyl msto nevyplovno)
\def\assgnname{p\v{r}\'{i}klad}
\def\dffield@assgn#1{\digitsright{2}{#1}{}}

% ID zadn generovanho testu
% (4 cifry,zarovnno doleva, zbyl msto nevyplovno)
\def\assgnidname{\v{c}\'{i}slo zad\'{a}n\'{i}}
\def\dffield@assgnid#1{\digitsleft{4}{#1}{}}

% slo listu
% (2 cifry, zarovnno vpravo, zbyl msto nevyplovno)
\def\sheetname{list}
\def\dffield@sheet#1{\digitsright{2}{#1}{}}


%%
%% Implementace strojov itelnch prvk - dek s selnmi daji
%%

% Makro vlo #1 na dek ky tiskovho zrcadla doplnn o bon vodic
% znaky pro rozpoznvn slic.
\def\digitsline#1{\hbox to \textwidth{%
    \hbox to 0pt{%
        \hss
        \digitsline@sidemarks
        \kern\size@rect@length % \rect@h pedstr, e m ku 0pt
        \kern\size@sync@skip
    }%
    #1\hfil
    \hbox to 0pt{%
        \kern\size@sync@skip
        \digitsline@sidemarks
        \hss
    }%
}}

% Tisk vodcch znaek na okrajch dku s selnmi daji.
\def\digitsline@sidemarks{%
    \lower \size@rect@shift \rect@h
    \rect@h
    \raise \size@rect@shift \rect@h
    \raise 2\size@rect@shift \rect@h
}


%%
%% Typ formule 7: assgnsheet
%% (body za strnku run psanch een)
%%

% Automatick potadlo list.
\newcounter{assgnsheet}

% Typ formule - konfigurace pro 'assgnsheet'
\let\as@formtype@do=\df@do
\def\as@formtype@skip{0pt}

% slo listu - konfigurace pro 'assgnsheet'
\let\as@sheet@do=\df@dolft
\def\as@sheet@skip{0.3\textwidth}

% UO - konfigurace pro 'assgnsheet'
\let\as@uco@do=\df@dolft
\def\as@uco@skip{0.5\textwidth}

% Body - konfigurace pro 'assgnsheet'
\let\as@points@do=\df@dolft
\def\as@points@skip{\textwidth\hss}

% \begin{assgnsheet}
% Lze zadat jeden nepovinn argument - slo pkladu.
\def\assgnsheet{%
    \@ifnextchar[
    {\csname as@assgnsheet\endcsname}
    {\csname as@assgnsheet\endcsname[\relax]}%
}

% Vlastn zahjen prosted.
\def\as@assgnsheet[#1]{%
    \def\as@arg{#1}%
    % formul zan na nov strnce
    \newpage
    % nastaven parametr strnky
    \hoffset = -1in
    \oddsidemargin = 2.2cm
    \evensidemargin = \oddsidemargin
    \textwidth = 16.6cm
    \voffset = -1in
    \topmargin = 1cm
    \headheight = 0cm
    \headsep = 0cm
    \textheight = \paperheight
    \advance\textheight by -2\topmargin
    \footskip = 0cm
    \hsize=\textwidth
    \@colht\textheight
    \@colroom\textheight \vsize\textheight
    % nastaven LaTeXovsk hlaviky a patiky
    \def\@oddfoot{}%
    \def\@evenfoot{}%
    % automatick potadlo list - jen kdy nen zadno slo explicitn
    \ifx \as@arg\loop@relax
        \stepcounter{assgnsheet}%
        \def\as@arg{\theassgnsheet}%
    \fi
    % povinn vodc znaky v zhlav strnky
    \marks@top
    % konfigurovateln text ped strojov itelnmi daji
    \as@pretext
    \ifx\as@pretext\empty \vskip \size@rect@shift\fi
    % strojov iteln daje
    \digitsline{%
        \digitsfield{as}{formtype}[7]%
        \digitsfield{as}{sheet}[\as@arg]%
        \digitsfield{as}{uco}%
        \digitsfield{as}{points}%
    }%
    % konfigurovateln text za strojov itelnmi daji
    \as@posttext
}

% Ukonen prosted.
\expandafter\def\csname endassgnsheet\endcsname{%
    % ukonen uivatelskho obsahu prosted a odskok na konec strnky
    \par\vfil
    % konfigurovateln text na konci strnky
    \as@bottomtext
    \vskip -\size@rect@length
    \marks@bottom
    \break
}

% Defaultn text pedchzejc slicovm informacm.
\def\as@pretext{}

% Defaultn text nsledujc tsn za slicovmi informacemi.
\def\as@posttext{%
    % sazba vzornku slic do boxu pro zjitn ky a vky
    \setbox0=\vbox{\hbox{%
            \size@rect@length=0.5\size@rect@length
            \size@rect@thick=0.5\size@rect@thick
            \size@refresh
            \digitsall
        }%
    }%
    % sazba textu do boxu pro zjitn vky
    \setbox1=\vbox{%
        \hsize=\textwidth
        \advance\hsize by -\wd0
        \advance\hsize by -2\size@rect@length
        \parindent=0pt
        \itshape
        Oblast strojov\v{e} sn\'{i}mateln\'{y}ch informac\'{i}. Sv\'{e} U\v{C}O
        vypl\v{n}te zleva dle p\v{r}i\-lo\v{z}en\'{e}ho vzoru \v{c}\'{i}slic. Jinak do
        t\'{e}to oblasti nezasahujte.\par
    }%
    \medskip
    \hbox to \textwidth{\box1\hfil\box0}
    \medskip
    \hrule height 1pt depth 0pt
}%

% Defaultn text na konci strnky.
\def\as@bottomtext{{%
    \hrule height 1pt depth 0pt
    \medskip
    \hsize=\textwidth
    \parindent=0pt
    \itshape Oblast strojov\v{e} sn\'{i}mateln\'{y}ch informac\'{i},
    nezasahujte. \bfseries \v{R}e\v{s}en\'{i} pi\v{s}te jen na tuto stranu.\par
}}

\endinput

